==> gm4_apple_trees_1_20.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Apple Trees by Gamemode 4

Apples don't grow on oak trees, silly Mojang! This datapack adds actual apple trees. Find them in forests or buy a sapling from a Wandering Trader.

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_apple_trees/images/apple_tree.png" alt="Apple Tree in a Forest" width="500"/>  

### Features:
- Apple trees naturally generate in Forests
    - Pick fully grown apples, or wait for them to fall on their own
    - Apples regrow every three 3 days
- Apple Saplings drop from chopped down trees, or can be bought from Wandering Traders
- If you're lucky, you might even find an ultra-rare golden apple tree in the wild

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/Apple_Trees)

### Credits
- Creators: [Bloo](https://twitter.com/Bloo_dev), [BluePsychoRanger](https://twitter.com/BluPsychoRanger), [SpecialBuilder32](https://twitter.com/SpecialBuilder)
- Icon Design: [BluePsychoRanger](https://twitter.com/BluPsychoRanger)

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.

==> gm4_apple_trees_1_21_5.zip: README.md <==
# <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="GM4 Logo" width="32" /> Apple Trees by Gamemode 4

Apples don't grow on oak trees, silly Mojang! This data pack adds actual apple trees. Find them in forests or buy a sapling from a Wandering Trader.

<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/gm4_apple_trees/images/apple_tree.png" alt="Apple Tree in a Forest" width="500"/>  

### Features
- Apple trees naturally generate in Forests
    - Pick fully grown apples, or wait for them to fall on their own
    - Apples regrow every three 3 days
- Apple Saplings drop from chopped down trees, or can be bought from Wandering Traders
- If you're lucky, you might even find an ultra-rare golden apple tree in the wild

### More Info
[<img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_wiki_logo.png" alt="Gamemode 4 Wiki Logo" width="40" align="center"/> **Read the Wiki**](https://wiki.gm4.co/wiki/Apple_Trees)

### Credits
- Creators: [Bloo](https://bsky.app/profile/bloo.boo), [BPR](https://bsky.app/profile/bpr02.com), [SpecialBuilder32](https://bsky.app/profile/specialbuilder32.bsky.social)
- Icon Design: [BPR](https://bsky.app/profile/bpr02.com)

---
## About Gamemode 4 <img src="https://raw.githubusercontent.com/Gamemode4Dev/GM4_Datapacks/master/base/images/gm4_logo.png" alt="Gamemode 4 Logo" width="20"/>
Gamemode 4 is a series of command-powered creations that are designed to change and enhance the survival experience. All of our modules are designed to work together flawlessly, and are balanced for usage in a survival setting. Pick and choose your favorites from our [website](https://gm4.co), or wherever you get datapacks.
